@@ -321,7 +321,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
         
         Usage::
 
-              ddr_show_trigger(device, 'cli', 'ShowInterfaceState', show_command, 1, 'Loopback1', 'none', 'none', 'admin_state', operator.eq, 'down', 10, 5, debug_flag=True)
+              ddr_show_trigger(device, 'loc', 'ShowInterfaceState', show_command, 1, 'Loopback1', 'none', 'none', 'admin_state', operator.eq, 'down', 10, 5, debug_flag=True)
 
             :raises none:
 
@@ -359,7 +359,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
         #
         # If access-type is cli use the Python CLI package to run command
         #
-            if str(access_type) == 'cli':
+            if str(access_type) == 'loc':
               response = cli.cli(command)
               ddr_debug_msg(debug_flag, f" ddr_show_trigger: cli python response: {str(response)}")
 
@@ -674,7 +674,7 @@ def ddr_nc_edit_config(device, access_type, datastore, commit, xpath, return_res
             
         Usage::
 
-              ddr_nc_edit_config(device, 'loc', 'running', True, xpath, True)
+              ddr_nc_edit_config(device, 'loc', 'running', False, xpath, True)
 
             :raises none:
     """
@@ -704,13 +704,6 @@ def ddr_nc_edit_config(device, access_type, datastore, commit, xpath, return_res
     #
     # get the subtree pointed to by the xpath
     #
-#PVH      with netconf_connection.locked(target=datastore):
-#        if datastore == 'running':
-#          result = netconf_connection.edit_config(config=xpath, target=datastore)
-#        else:
-#          netconf_connection.edit_config(config=xpath, target=datastore)
-#          result = netconf_connection.commit(confirmed=True)
-#      netconf_connection.unlock(target=datastore)
       ddr_debug_msg(debug_flag, f"ddr_nc_edit_config xpath: {str(xpath)} datastore: {str(datastore)}")
       result = netconf_connection.edit_config(config=str(xpath), target=datastore)
       netconf_connection.close_session()            
@@ -744,7 +737,7 @@ def ddr_nc_get_parameter(device, access_type, xpath, pcount, par1, par2, par3, l
         
         Usage::
 
-              ddr_nc_get_parameter(device, 'cli', xpath, 1, interface_name, "none", "none", "admin-status", True, debug_flag=True)
+              ddr_nc_get_parameter(device, 'loc', xpath, 1, interface_name, "none", "none", "admin-status", True, debug_flag=True)
 
             :raises none:
     """
@@ -890,7 +883,7 @@ def ddr_cli_command(device, access_type, command, return_response, timestamp, de
     #
     # If access-type is cli use the Python CLI package to run command
     #
-      if str(access_type) == 'cli':
+      if str(access_type) == 'loc':
           if return_response:
               response = cli.cli(cli_command)
               ddr_debug_msg(debug_flag, f"ddr_cli_command: {str(cli_command)} response: {str(response)}")
@@ -952,7 +945,7 @@ def ddr_cli_configure(device, access_type, command, return_response, timestamp,
     #
     # If access-type is cli use the Python CLI package to apply configuration
     #
-      if str(access_type) == 'cli':
+      if str(access_type) == 'loc':
           if return_response:
               response = cli.configure(cli_command)
               ddr_debug_msg(debug_flag, f"ddr_cli_configure: {str(cli_command)} response: {str(response)}")
@@ -1060,28 +1053,26 @@ def ddr_trigger_notify(device, triggers, debug_flag=False):
     notify_conn.close_session()
     return notify_xml
 
-def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2, par3, match_string, log_path, debug_flag=False):
+def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2, par3, log_path, debug_flag=False):
 
     """
-         Decode a btrace log file on the device, find lines containing a match_string, return the matched lines and save the decoded log
+         Decode a btrace log file on the device and save the decoded log
          
         :param device: Device identity and credentials
         :param access_type: "cli" or "ssh" for type of exec CLI access
         :param show_template: string with 0 to 3 parameters that is used to read the btrace file
         :param pcount: Number of parameters to substitute in the xpath 0 to 3
         :param parx: Values for parmeters 1, 2 and 3
-        :param match_string: String contained in btrace log file lines used to select the lines to include in the results
         :param log_path: path to where the decoded btrace log should be saved
         :param debug_flag: True to enable debug output for this call, False no debug output (default)
                 
         Usage::
 
-          ddr_decode_btrace_log(device, "cli", "show logging process {0} start last {1} minutes", 2, "dmiauthd", 20, "none", "%DMI-5-AUTH_PASSED:", "/bootflash/guest-share/Btrace_dmiauthd_log", debug_flag=False)
+          ddr_decode_btrace_log(device, "cli", "show logging process {0} start last {1} minutes", 2, "dmiauthd", 20, "none",  "/bootflash/guest-share/ddr/ddr_decode_btrace/ddr_btrace_dmiauthd", debug_flag=False)
 
        :raises none:
 
     """
-    timestamp =  datetime.now().strftime("%m-%d-%Y_%H:%M:%S.%f")
           
     #######################################################################
     #
@@ -1106,9 +1097,13 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
     #
     # If access-type is cli use the Python CLI package to run command
     #
-      if str(access_type) == 'cli':
+      if debug_flag:
+          ddr_info_msg("ddr_decode_btrace_log device command: " + str(command))
+      if str(access_type) == 'loc':
         try:
           response = cli.cli(command)
+          if debug_flag:
+              ddr_info_msg("ddr_decode_btrace_log cli command response: " + str(response))
         except:
           ddr_error_msg("run_decode_btrace_log cli access method not available")
           raise
@@ -1127,6 +1122,8 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
           child.sendline(device[3])
           child.expect(pexpect.EOF)
           response = child.before
+          if debug_flag:
+              ddr_info_msg("ddr_decode_btrace_log ssh command response: " + str(response))
 
         except Exception as e:
           child.close()
@@ -1138,34 +1135,19 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
       ddr_error_msg("run_decode_btrace_log: Exception sending show command: {str(e)}")
       raise
     #
-    # Search for content in log file
-    #
-    matched_lines = []
-    try:
-      match_pattern = ".*" + str(match_string) + ".*"
-      p1 = re.compile(match_pattern)
-      for line in response.splitlines():
-        line = line.strip()
-        m = p1.match(line)
-        if m:
-          matched_lines.append(line)
-    except Exception as e:
-      ddr_error_msg("run_decode_btrace_log regex: {str(match_string)} {str(e)}")
-      raise
-
-    #
     # Save decoded btrace log if required
     #
     if log_path != "none":
       try:
-        out_path = str(log_path) + "_" + str(timestamp)
+        out_path = str(log_path)
         with open(out_path, 'w') as wfd:
           wfd.write(response)
           wfd.close()
       except Exception as e:
         ddr_error_msg("run_decode_btrace_log: Exception saving btrace log: {str(e)}")
         raise
-    return matched_lines
+
+    return
     
 def ddr_control_file(control_file, delay):
     """
@@ -1215,7 +1197,7 @@ def ddr_show_parameter_all(device, access_type, genie_parser_name, show_template
                 * Return the show command parameters in a python dictionary
 
             :param device: Device information and credentials for running show command
-            :param access_type: 'cli' to use the Python cli package in the guestshell
+            :param access_type: 'loc' to use the Python cli package in the guestshell
             :param genie_parser_name: genie parser to use to process show command
             :param show_template: show command to execute with optional parameters identified by {0}, {1}, {2}
             :param pcount: Number of parameters to substitute in the show_command 0 to 3
@@ -1224,7 +1206,7 @@ def ddr_show_parameter_all(device, access_type, genie_parser_name, show_template
         
         Usage::
 
-              ddr_show_parameter_all(device, 'cli', 'ShowInterface', 'show interface {0}', 1, 'GigabitEthernet0/0', 'none', 'none', 'GigabitEthernet0/0', debug_flag=True)
+              ddr_show_parameter_all(device, 'loc', 'ShowInterface', 'show interface {0}', 1, 'GigabitEthernet0/0', 'none', 'none', 'GigabitEthernet0/0', debug_flag=True)
 
             :raises none:
 
@@ -1251,7 +1233,7 @@ def ddr_show_parameter_all(device, access_type, genie_parser_name, show_template
         #
         # If access-type is cli use the Python CLI package to run command
         #
-          if str(access_type) == 'cli':
+          if str(access_type) == 'loc':
             ddr_debug_msg(debug_flag, f" ddr_show_parameter_all: cli python command: {str(command)}")
             response = cli.cli(command)
             ddr_debug_msg(debug_flag, f" ddr_show_parameter_all: cli python response: {str(response)}")
